@@ -41,7 +41,8 @@ from ansiblelint.color import (
     reconfigure,
     render_yaml,
 )
-from ansiblelint.config import options, used_old_tags
+from ansiblelint.config import options
+from ansiblelint.constants import ANSIBLE_MISSING_RC, EXIT_CONTROL_C_RC
 from ansiblelint.file_utils import cwd
 from ansiblelint.skip_utils import normalize_tag
 from ansiblelint.version import __version__
@@ -55,7 +56,13 @@ _logger = logging.getLogger(__name__)
 
 def initialize_logger(level: int = 0) -> None:
     """Set up the global logging level based on the verbosity number."""
-    VERBOSITY_MAP = {0: logging.NOTSET, 1: logging.INFO, 2: logging.DEBUG}
+    VERBOSITY_MAP = {
+        -2: logging.ERROR,
+        -1: logging.WARNING,
+        0: logging.NOTSET,
+        1: logging.INFO,
+        2: logging.DEBUG,
+    }
 
     handler = logging.StreamHandler()
     formatter = logging.Formatter('%(levelname)-8s %(message)s')
@@ -75,9 +82,15 @@ def initialize_options(arguments: List[str]):
     new_options.cwd = pathlib.Path.cwd()
 
     if new_options.version:
-        print('ansible-lint {ver!s}'.format(ver=__version__))
-        # assure we fail if ansible is missing, even for version printing
-        check_ansible_presence()
+        ansible_version, err = check_ansible_presence()
+        print(
+            'ansible-lint {ver!s} using ansible {ansible_ver!s}'.format(
+                ver=__version__, ansible_ver=ansible_version
+            )
+        )
+        if err:
+            _logger.error(err)
+            sys.exit(ANSIBLE_MISSING_RC)
         sys.exit(0)
 
     if new_options.colored is None:
@@ -124,13 +137,20 @@ warn_list:  # or 'skip_list' to silence them completely
             break
     msg += "".join(sorted(entries))
 
-    for k, v in used_old_tags.items():
-        _logger.warning(
-            "Replaced deprecated tag '%s' with '%s' but it will become an "
-            "error in the future.",
-            k,
-            v,
-        )
+    # Do not deprecate the old tags just yet. Why? Because it is not currently feasible
+    # to migrate old tags to new tags. There are a lot of things out there that still
+    # use ansible-lint 4 (for example, Ansible Galaxy and Automation Hub imports). If we
+    # replace the old tags, those tools will report warnings. If we do not replace them,
+    # ansible-lint 5 will report warnings.
+    #
+    # We can do the deprecation once the ecosystem caught up at least a bit.
+    # for k, v in used_old_tags.items():
+    #     _logger.warning(
+    #         "Replaced deprecated tag '%s' with '%s' but it will become an "
+    #         "error in the future.",
+    #         k,
+    #         v,
+    #     )
 
     if result.matches and not options.quiet:
         console_stderr.print(
@@ -163,7 +183,7 @@ def main(argv: List[str] = None) -> int:
     app = App(options=options)
 
     prepare_environment()
-    check_ansible_presence()
+    check_ansible_presence(exit_on_error=True)
 
     # On purpose lazy-imports to avoid pre-loading Ansible
     # pylint: disable=import-outside-toplevel
@@ -256,6 +276,8 @@ def _run_cli_entrypoint() -> None:
         # NOTE: Only "broken pipe" is acceptable to ignore
         if exc.errno != errno.EPIPE:
             raise
+    except KeyboardInterrupt:
+        sys.exit(EXIT_CONTROL_C_RC)
     except RuntimeError as e:
         raise SystemExit(str(e))
 
