@@ -22,7 +22,7 @@ import pytest
 
 from ansiblelint.rules.MissingFilePermissionsRule import MissingFilePermissionsRule
 
-SUCCESS_TASKS = '''
+SUCCESS_TASKS = '''\
 ---
 - hosts: hosts
   tasks:
@@ -50,9 +50,13 @@ SUCCESS_TASKS = '''
     - name: replace should not require mode
       replace:
         path: foo
+    - name: file with recursive does not require mode
+      file:
+        state: directory
+        recurse: yes
 '''
 
-FAIL_TASKS = '''
+FAIL_TASKS = '''\
 ---
 - hosts: hosts
   tasks:
@@ -68,10 +72,10 @@ FAIL_TASKS = '''
       file:
         path: foo
         state: directory
-    - name: permissions needed if create is used
-      ini_file:
-        path: foo
-        create: true
+    # - name: permissions needed if create is used
+    #   ini_file:
+    #     path: foo
+    #     create: true
     - name: lineinfile when create is true
       lineinfile:
         path: foo
@@ -81,30 +85,34 @@ FAIL_TASKS = '''
       replace:
         path: foo
         mode: preserve
-    - name: ini_file does not accept preserve mode
-      ini_file:
-        path: foo
-        create: true
-        mode: preserve
+    # - name: ini_file does not accept preserve mode
+    #   ini_file:
+    #     path: foo
+    #     create: true
+    #     mode: preserve
 '''
 
 
-@pytest.mark.parametrize('rule_runner', (MissingFilePermissionsRule, ), indirect=['rule_runner'])
-def test_success(rule_runner):
+@pytest.mark.parametrize(
+    'rule_runner', (MissingFilePermissionsRule,), indirect=['rule_runner']
+)
+def test_success(rule_runner) -> None:
     """Validate that mode presence avoids hitting the rule."""
     results = rule_runner.run_playbook(SUCCESS_TASKS)
     assert len(results) == 0
 
 
-@pytest.mark.parametrize('rule_runner', (MissingFilePermissionsRule, ), indirect=['rule_runner'])
-def test_fail(rule_runner):
+@pytest.mark.parametrize(
+    'rule_runner', (MissingFilePermissionsRule,), indirect=['rule_runner']
+)
+def test_fail(rule_runner) -> None:
     """Validate that missing mode triggers the rule."""
     results = rule_runner.run_playbook(FAIL_TASKS)
-    assert len(results) == 7
-    assert results[0].linenumber == 5
-    assert results[1].linenumber == 9
-    assert results[2].linenumber == 13
-    assert results[3].linenumber == 17
-    assert results[4].linenumber == 21
-    assert results[5].linenumber == 26
-    assert results[6].linenumber == 30
+    assert len(results) == 5
+    assert results[0].linenumber == 4
+    assert results[1].linenumber == 8
+    assert results[2].linenumber == 12
+    # assert results[3].linenumber == 16
+    assert results[3].linenumber == 20
+    assert results[4].linenumber == 25
+    # assert results[6].linenumber == 29
