@@ -13,12 +13,12 @@ class TestNoFormattingInWhenRule(unittest.TestCase):
         self.collection.register(NoFormattingInWhenRule())
 
     def test_file_positive(self):
-        success = 'test/jinja2-when-success.yml'
-        good_runner = Runner(self.collection, success, [], [], [])
+        success = 'examples/playbooks/jinja2-when-success.yml'
+        good_runner = Runner(success, rules=self.collection)
         self.assertEqual([], good_runner.run())
 
     def test_file_negative(self):
-        failure = 'test/jinja2-when-failure.yml'
-        bad_runner = Runner(self.collection, failure, [], [], [])
+        failure = 'examples/playbooks/jinja2-when-failure.yml'
+        bad_runner = Runner(failure, rules=self.collection)
         errs = bad_runner.run()
         self.assertEqual(2, len(errs))
