@@ -13,16 +13,8 @@ TASK_MINIMAL = """
   ping:
 """
 
-ROLE_MINIMAL = {
-    'tasks': {
-        'main.yml': TASK_MINIMAL
-    }
-}
-ROLE_META_EMPTY = {
-    'meta': {
-        'main.yml': ''
-    }
-}
+ROLE_MINIMAL = {'tasks': {'main.yml': TASK_MINIMAL}}
+ROLE_META_EMPTY = {'meta': {'main.yml': ''}}
 
 ROLE_WITH_EMPTY_META = {**ROLE_MINIMAL, **ROLE_META_EMPTY}
 
@@ -34,7 +26,7 @@ PLAY_INCLUDE_ROLE = f"""
 
 
 @pytest.fixture
-def test_rules_collection():
+def test_rules_collection() -> RulesCollection:
     """Instantiate a roles collection for tests."""
     collection = RulesCollection()
     collection.register(RoleNames())
@@ -66,15 +58,20 @@ def playbook_path(request, tmp_path):
     return str(play_path)
 
 
-@pytest.mark.parametrize(('playbook_path', 'messages'), (
-        pytest.param((PLAY_INCLUDE_ROLE, ROLE_NAME_VALID, ROLE_WITH_EMPTY_META),
-                     [],
-                     id='ROLE_EMPTY_META',
-                     ),
-), indirect=('playbook_path',))
+@pytest.mark.parametrize(
+    ('playbook_path', 'messages'),
+    (
+        pytest.param(
+            (PLAY_INCLUDE_ROLE, ROLE_NAME_VALID, ROLE_WITH_EMPTY_META),
+            [],
+            id='ROLE_EMPTY_META',
+        ),
+    ),
+    indirect=('playbook_path',),
+)
 def test_role_name(test_rules_collection, playbook_path, messages):
     """Lint a playbook and compare the expected messages with the actual messages."""
-    runner = Runner(test_rules_collection, playbook_path, [], [], [])
+    runner = Runner(playbook_path, rules=test_rules_collection)
     results = runner.run()
     assert len(results) == len(messages)
     results_text = str(results)
