@@ -13,12 +13,12 @@ class TestTaskHasNameRule(unittest.TestCase):
         self.collection.register(TaskHasNameRule())
 
     def test_file_positive(self):
-        success = 'test/task-has-name-success.yml'
-        good_runner = Runner(self.collection, success, [], [], [])
+        success = 'examples/playbooks/task-has-name-success.yml'
+        good_runner = Runner(success, rules=self.collection)
         self.assertEqual([], good_runner.run())
 
     def test_file_negative(self):
-        failure = 'test/task-has-name-failure.yml'
-        bad_runner = Runner(self.collection, failure, [], [], [])
+        failure = 'examples/playbooks/task-has-name-failure.yml'
+        bad_runner = Runner(failure, rules=self.collection)
         errs = bad_runner.run()
-        self.assertEqual(2, len(errs))
+        self.assertEqual(4, len(errs))
