@@ -227,7 +227,7 @@ def test_get_yaml_files_git_verbose(reset_env_var, message_prefix, monkeypatch,
     expected_info = (
         "ansiblelint",
         logging.INFO,
-        'Discovering files to lint: git ls-files -z *.yaml *.yml',
+        'Discovering files to lint: git ls-files -z',
     )
 
     assert expected_info in caplog.record_tuples
@@ -312,7 +312,7 @@ def test_cli_auto_detect(capfd):
     out, err = capfd.readouterr()
 
     # Confirmation that it runs in auto-detect mode
-    assert "Discovering files to lint: git ls-files -z *.yaml *.yml" in err
+    assert "Discovering files to lint: git ls-files -z" in err
     # An expected rule match from our examples
     assert (
         "examples/playbooks/empty_playbook.yml:0: "
@@ -344,6 +344,11 @@ def test_is_playbook():
         ("roles/foo/molecule/scen1/molecule.yml", "yaml"),  # molecule scenario config
         ("roles/foo/molecule/scen2/foobar.yml", "playbook"),  # custom playbook name
         ("roles/foo/molecule/scen3/converge.yml", "playbook"),  # common playbook name
+        ("roles/foo/molecule/scen3/requirements.yml", "requirements"),  # requirements
+        ("roles/foo/molecule/scen3/collections.yml", "requirements"),  # requirements
+        # tasks files:
+        ("tasks/directory with spaces/main.yml", "tasks"),  # tasks
+        ("tasks/requirements.yml", "tasks"),  # tasks
         # requirements (we do not support includes yet)
         ("requirements.yml", "requirements"),  # collection requirements
         ("roles/foo/meta/requirements.yml", "requirements"),  # inside role requirements
@@ -355,10 +360,15 @@ def test_is_playbook():
         ("examples/playbooks/vars/other.yml", "vars"),
         ("examples/playbooks/vars/subfolder/settings.yml", "vars"),  # deep vars
         ("molecule/scenario/collections.yml", "requirements"),  # deprecated 2.8 format
+        (
+            "../roles/geerlingguy.mysql/tasks/configure.yml",
+            "tasks",
+        ),  # relative path involved
+        ("galaxy.yml", "galaxy"),
     ),
 )
-def test_auto_detect(monkeypatch, path: str, kind: FileType) -> None:
-    """Verify auto-detection logic."""
+def test_default_kinds(monkeypatch, path: str, kind: FileType) -> None:
+    """Verify auto-detection logic based on DEFAULT_KINDS."""
     options = cli.get_config([])
 
     def mockreturn(options):
